@@ -6,7 +6,7 @@
 */
 
 /*
-* Phamm - http://phamm.rhx.it - <phamm@rhx.it>
+* Phamm - http://www.phamm.org - <team@phamm.org>
 * Copyright (C) 2004,2008 Alessandro De Zorzi and Mirko Grava
 *
 * This file is part of Phamm.
@@ -164,9 +164,25 @@ function phamm_set_var($name, $values=null, $methods=null, $level=0)
     return null;
 }
 
-function phamm_print_message ($class,$message,$newline=true)
+function phamm_print_message ($class,$message,$newline=false)
 {
-    echo '<font class="'.$class.'">'.$message.'</font>';
+    switch ($class) :
+	
+	case "error" :
+	    $msg = _('Error: ').$message;
+	break;
+	
+	case "warning" :
+	    $msg = _('Warning: ').$message;
+	break;
+	
+	default :
+	    $msg = $message;
+	break;
+
+    endswitch;
+
+    echo '<div class="'.$class.'">'.$msg.'</div>';
 
     if ($newline)
         echo '<br/>';
@@ -178,15 +194,18 @@ function phamm_print_xhtml ($tag)
 }
 
 /*
+* Execute a command to multiple accounts/domains
 *
+* @param string $command The command
+* @param array $values Lists of accounts/domains
 */
 
-function group_actions ($group_action,$values)
+function group_actions ($command,$values)
 {
     // Set initial return value
     $r = false;
 
-    $ga = explode(';',$group_action);
+    $ga = explode(';',$command);
 
     $mode = $ga[0];
 
@@ -209,12 +228,12 @@ function group_actions ($group_action,$values)
             $entry[$ga[1]] = (string)$ga[2];
 	    
 	    $is_alias = (in_array('VirtualMailAlias',($self_values[0]["objectclass"])) ? true : false);
-
+    
+	    // Delete immediate if VirtualMailAlias
 	    if (isset($entry["delete"]) && $is_alias)
-		// Delete immediate if VirtualMailAlias
 		$r = phamm_ldap_delete($dn,$recursive=false);
+	    // Change single value
 	    else
-		// Change single value
 		$r = phamm_modify ($dn,$entry);
         }
 
@@ -259,4 +278,5 @@ case "postmaster" :
     return $r;
 }
 
+
 ?>
