@@ -6,7 +6,7 @@
 **/
 
 /*
-* Phamm - http://phamm.rhx.it - <phamm@rhx.it>
+* Phamm - http://www.phamm.org - <team@phamm.org>
 * Copyright (C) 2004,2008 Alessandro De Zorzi and Mirko Grava
 *
 * This file is part of Phamm.
@@ -28,6 +28,8 @@
 
 function page_start()
 {
+    global $action;
+
     $tag = '<?xml version="1.0" encoding="UTF-8"?>';
 
     $tag .= '<!DOCTYPE html'."\n";
@@ -36,7 +38,10 @@ function page_start()
 
     $tag .= '<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">'."\n";
     $tag .= '<head>'."\n";
-    $tag .= "\t".'<title>'.ORG_TITLE.'</title>'."\n";
+    $tag .= "\t".'<title>'.ORG_TITLE;
+    if (isset($action))
+	$tag .= ' - '.str_replace('_',' ',$action);
+    $tag .= '</title>'."\n";
     $tag .= "\t".'<style type="text/css" media="all">@import "./style/phamm/main.css";</style>'."\n";
     $tag .= "\t".'<script type="text/javascript" src="functions.js"></script>'."\n";
     $tag .= '</head>'."\n";
@@ -47,8 +52,6 @@ function page_start()
 
 function page_end()
 {
-    global $lang;
-
     $tag = '<hr/>';
     $tag .= '<a href="'.ORG_URL.'" target="_blank">';
     $tag .= '<img src="'.ORG_LOGO.'" ';
@@ -57,7 +60,7 @@ function page_end()
     if (HIDE_VERSION != 1)
     {
         $tag .="<font class=\"note\">Phamm";
-        $tag .= $lang["version_short"].' '.VERSION;
+        $tag .= sprintf(_("Ver. %s"),VERSION);
         $tag .= "</font>";
     }
 
@@ -82,20 +85,18 @@ function page_exit()
 
 function login_form()
 {
-    global $lang;
-
     if (isset($_POST["login_username"]))
         $login_username = $_POST["login_username"];
     else
         $login_username = null;
 
-    $tag = "<a href=\"http://phamm.rhx.it/\">"."\n";
-    $tag .= "<img src=\"./img/phamm_100.png\" alt=\"Phamm logo\" border=\"0\" /></a>"."\n";
+    $tag = '<a href="'.ORG_URL.'">'."\n";
+    $tag .= "<img src=\"img/phamm_100.png\" alt=\"Phamm logo\" border=\"0\" /></a>"."\n";
 
     if (HIDE_VERSION != 1)
     {
         $tag .= "<font class=\"note\">";
-        $tag .= $lang["version_short"].' '.VERSION;
+        $tag .= sprintf(_("Ver. %s"),VERSION);
         $tag .= "</font>"."\n";
     }
 
@@ -103,13 +104,13 @@ function login_form()
     $tag .= "<form method=\"post\" action=\"".$_SERVER["PHP_SELF"]."\" name=\"login\">"."\n";
     $tag .= "<input type=\"hidden\" name=\"action\" value=\"login\" />"."\n";
     $tag .= "<table class=\"data\">"."\n";
-    $tag .= "<tr><td>".$lang["login"]."</td>"."\n";
+    $tag .= "<tr><td>"._("Login Name")."</td>"."\n";
     $tag .= "<td><input type=\"text\" size=\"25\" name=\"login_username\" value=\"".$login_username."\" maxlength=\"100\" /></td></tr>"."\n";
-    $tag .= "<tr><td>".$lang["password"]."</td>"."\n";
+    $tag .= "<tr><td>"._("Password")."</td>"."\n";
     $tag .= "<td><input type=\"password\" size=\"25\" name=\"login_password\" value=\"\" maxlength=\"50\" /></td></tr>"."\n";
     $tag .= "</table>"."\n";
 
-    $tag .= "<input type=\"submit\" value=\"".$lang["login"]."\" />"."\n";
+    $tag .= "<input type=\"submit\" value=\""._("Login")."\" />"."\n";
     $tag .= "</form>"."\n";
 
     return $tag;
@@ -144,14 +145,17 @@ function style_load($style)
 
 function domains_list($vds,$values)
 {
-    global $lang;
-
     $tag = '<form method="post" action="'.$_SERVER["PHP_SELF"].'" name="domains" id="post-checks">';
     $tag .= '<table class="data">';
 
-    $tag .= '<tr class="header">';
-    $tag .= '<td><input type="checkbox" name="all" onclick="checkAll();" /></td>';
-    $tag .= '<td>'.$lang["domain"].' ('.$vds["count"].')</td>'."\n";
+    $tag .= '<thead>';
+    $tag .= '<tr>';
+    $tag .= '<th><input type="checkbox" name="all" onclick="checkAll();" /></th>';
+    $tag .= '<th>';
+    $tag .= sprintf(ngettext("Domain (%d)", "Domains (%d)", $vds["count"]), $vds["count"]);
+
+    
+    $tag .= '</th>'."\n";
 
     if (isset($values["ATTRIBUTES"]))
     {
@@ -160,14 +164,16 @@ function domains_list($vds,$values)
 	    // Show only attributes with <table> value
 	    if (isset($values["ATTRIBUTES"][$key]["TABLE"]))
 	    {
-		$label = (isset($lang[$key]) ? $lang[$key] : $key);
-		$tag .= '<td>'.$label.'</td>'."\n";
+		$label = (isset($values["ATTRIBUTES"][$key]["PRETTYNAME"]) ? $values["ATTRIBUTES"][$key]["PRETTYNAME"] : $key);
+		$tag .= '<th>'.gettext($label).'</th>'."\n";
 	    }
         }
     }
 
     $tag .= '</tr>';
+    $tag .= '</thead>';
 
+    $tag .= '<tbody>';
 
     foreach ($vds as $vd)
     {
@@ -213,7 +219,7 @@ function domains_list($vds,$values)
 			    if (isset($values["ATTRIBUTES"][$key]["TABLENOEDIT"]))
 				$tag .= $val;
 			    elseif (isset($values["ATTRIBUTES"][$key]["BOOL"]))
-				$tag .= tof_icon('domains['.$domain.']',$val,'domain;'.$key.';'.$rev,$reverse,$cron);
+				$tag .= tof_icon('domains['.$domain.']',$val,'group_actions&amp;command=domain;'.$key.';'.$rev,$reverse,$cron);
 			    else
 				$tag .= $val;
 			}
@@ -226,7 +232,7 @@ function domains_list($vds,$values)
 			    $rev = ($val == 'TRUE' ? 'FALSE' : 'TRUE');
 
 			    if ($val == 'TRUE' || $val == 'FALSE')
-				$tag .= tof_icon('domains['.$domain.']',$val,'postmaster;'.$key.';'.$rev,$reverse,$cron);
+				$tag .= tof_icon('domains['.$domain.']',$val,'group_actions&amp;command=postmaster;'.$key.';'.$rev,$reverse,$cron);
 			    else
 				$tag .= $val;
 			}
@@ -240,6 +246,7 @@ function domains_list($vds,$values)
         }
     }
 
+    $tag .= '</tbody>';
     $tag .= '</table>';
 
     // End </form> tag inside action_select() function
@@ -253,9 +260,9 @@ function domains_list($vds,$values)
 
 function accounts_list($domain,$values,$initial)
 {
-    global $lang;
     global $pn;
     global $pv;
+    global $action;
     
     // Rapresentative ObjectClass
     $myObjectClass = (isset($pv[$pn]["ACCOUNT"]["OBJECTCLASSES"]) ? key($pv[$pn]["ACCOUNT"]["OBJECTCLASSES"]) : 'virtualMailAccount');
@@ -268,10 +275,13 @@ function accounts_list($domain,$values,$initial)
     $tag = '<form method="post" action="'.$_SERVER["PHP_SELF"].'" name="accounts" id="post-checks">';
     $tag .= '<table class="data">';
 
-    $tag .= '<tr class="header">';
-    $tag .= '<td><input type="checkbox" name="all" onclick="checkAll();" /></td>';
-    $tag .= '<td>'.$lang["account"].' ('.$account_array["count"].')</td>'."\n";
-    $tag .= '<td>'.$lang["cn"].'</td>'."\n";
+    $tag .= '<thead>';
+    $tag .= '<tr>';
+    $tag .= '<th><input type="checkbox" name="all" onclick="checkAll();" /></th>';
+    $tag .= '<th>';
+    $tag .= sprintf(ngettext("Account (%d)", "Accounts (%d)", $account_array["count"]), $account_array["count"]);
+    $tag .= '</th>'."\n";
+    $tag .= '<th>'._("Common Name").'</th>'."\n";
 
     if (count($values) > 0)
     {
@@ -279,13 +289,15 @@ function accounts_list($domain,$values,$initial)
         {
 	    if (isset($values["ATTRIBUTES"][$key]["TABLE"]))
 	    {
-		$label = (isset($lang[$key]) ? $lang[$key] : $key);
-		$tag .= '<td>'.$label.'</td>'."\n";
+		$label = (isset($values["ATTRIBUTES"][$key]["PRETTYNAME"]) ? $values["ATTRIBUTES"][$key]["PRETTYNAME"] : $key);
+		$tag .= '<th>'.gettext($label).'</th>'."\n";
 	    }
         }
     }
     $tag .= '</tr>';
-
+    $tag .= '</thead>';
+    
+    $tag .= '<tbody>';
 
     foreach ($account_array as $account)
     {
@@ -325,12 +337,12 @@ function accounts_list($domain,$values,$initial)
 			    if (isset($values["ATTRIBUTES"][$key]["TABLENOEDIT"]))
 				$tag .= $val;
 			    elseif (isset($values["ATTRIBUTES"][$key]["BOOL"]))
-				$tag .= tof_icon('accounts['.$mail.']',$val,'account;'.$key.';'.$rev,$reverse,$cron);
+				$tag .= tof_icon('accounts['.$mail.']',$val,'group_actions&amp;command=account;'.$key.';'.$rev,$reverse,$cron);
 
 			    // Print Standard Value
 			    else
 			    {
-				if (isset($value["MULTIPLIER"]))
+				if (isset($value["MULTIPLIER"]) && in_array($action,array('modify_account','domain_property','domain_view')))
 				    $tag .= $account[$key_lower][0] / $value["MULTIPLIER"];
 				else
 				    $tag .= $val;
@@ -347,6 +359,7 @@ function accounts_list($domain,$values,$initial)
         }
     }
 
+    $tag .= '</tbody>';
     $tag .= '</table>';
 
     return $tag;
@@ -359,15 +372,13 @@ function accounts_list($domain,$values,$initial)
 
 function form_add_domain ()
 {
-    global $lang;
-
     $tag = '<form method="post" action="'.$_SERVER["PHP_SELF"].'" name="add_domain">';
     $tag .= '<input type="hidden" name="action" value="add_domain" />';
     $tag .= '<input type="text" size="25" name="domain_new"  maxlength="50" value="';
     if (isset($_POST["domain_new"]))
         $tag .= $_POST["domain_new"];
     $tag .= '" />';
-    $tag .= '<input type="submit" value="'.$lang["add_domain"].'" />';
+    $tag .= '<input type="submit" value="'._("Add new domain").'" />';
     $tag .= '</form>';
 
     return $tag;
@@ -385,7 +396,6 @@ function form_add_domain ()
 
 function form_template($p_name,$attributes,$myvalues,$skip_table=null)
 {
-    global $lang;
     global $action;
     global $minAuthLevel;
 
@@ -432,7 +442,7 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
 	}
 
 	// Multiplier (Ex. Quota x 1024)
-	if (isset($attr["MULTIPLIER"]) && !in_array($action,array('add_account','insert_account')))
+	if (isset($attr["MULTIPLIER"]) && in_array($action,array('modify_account','domain_property')))
 	{
 		$value = ( $value / $attr["MULTIPLIER"]);
 	}
@@ -472,6 +482,20 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
 
                 break;
 
+		// Call PHP Function
+		default :
+		    
+		    if (function_exists($function_name))
+		    {
+			// Escape a string to be used as a shell argument
+			foreach ($args as $arg)
+			    $args_escaped = escapeshellarg($arg);
+		    
+			    $value = call_user_func_array($function_name,$args_escaped); 
+		    }
+
+                break;
+
                 endswitch;
             }
 
@@ -483,13 +507,24 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
 
 	// Hide values if SUBORDINATED to another
 	if (isset($attr["SUBORDINATED"]))
-	    $hidden = ($myvalues[0][strtolower($subordinated)][0] == "TRUE" ? null : 1);
+	{
+	    if (isset($myvalues[0][strtolower($subordinated)][0]))    
+		$hidden = ($myvalues[0][strtolower($subordinated)][0] == "TRUE" ? null : 1);
+	    else
+		$hidden = 1;
+	}
 	if (isset($attr["SUBORDINATEDREVERSE"]))
-	    $hidden = ($myvalues[0][strtolower($subordinatedreverse)][0] == "FALSE" ? null : 1);
+	{
+	    if (isset($myvalues[0][strtolower($subordinatedreverse)][0]))
+		$hidden = ($myvalues[0][strtolower($subordinatedreverse)][0] == "FALSE" ? null : 1);
+	    else
+		$hidden = 1;
+	}
 	    
         if (!isset($hidden))
         {
-            $tag .= (isset($lang[$key]) ? $lang[$key] : $key);
+            $label = (isset($attr["PRETTYNAME"]) ? $attr["PRETTYNAME"] : $key);
+            $tag .= gettext($label);
 	    $tag .= $required;
         
 	    $tag .= "</td><td>";
@@ -514,7 +549,8 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
 		$tag .= '<select name="values['.$p_name.']['.$name.']">';
 		foreach ($attr["OPTIONS"] as $k => $v)
 		{
-		    $label = (isset($lang[$k]) ? $lang[$k] : $k);
+		    $label = (isset($attr["PRETTYNAME"]) ? $attr["PRETTYNAME"] : $k);
+		    $label = $k;
 		    $selected = ($value == $v["VALUE"] ? 'selected="selected"' : '');
 		
 		    $tag .= '<option value="'.$v["VALUE"].'" '.$selected.'>'.$label.' ('.$v["VALUE"].')</option>'."\n";
@@ -602,22 +638,6 @@ function form_template($p_name,$attributes,$myvalues,$skip_table=null)
     return $tag;
 }
 
-/**
-*
-**/
-
-function plugin_bar()
-{
-    global $lang;
-
-    $tag = "<tr class=\"plugin_bar\"><td>".$lang["plugin"]."</td>";
-    $tag .= "<td>".$lang["template"]."</td>";
-    $tag .=  "<td>".$lang["custom_values"]."<br/>
-             <font class=\"note_white\">(".$lang["overwrite_template_values"].")</font></td></tr>";
-
-    return $tag;
-}
-
 /**
 * Print a form to add or modify a domain
 *
@@ -625,19 +645,21 @@ function plugin_bar()
 * @author Alessandro De Zorzi <adezorzi@rhx.it>
 *
 * @param string $domain_new
+* @param string $action
+* @param array $values
+* @return mixed
 **/
 
-function form_add_domain_2 ($domain_new,$action)
+function form_add_domain_2 ($domain_new, $action, $values, $values_postmaster)
 {
-    global $lang;
     global $plugins;
     global $pv;
-    global $values;
+    global $domain;
     
     if (in_array($action,array('update_account','modify_account')))
-	$submit_label = $lang["modify_domain"];
+	$submit_label = _("Modify domain");
     else
-	$submit_label = $lang["add_domain"];
+	$submit_label = _("Add new domain");
 
     $tag = '<form method="post" action="'.$_SERVER["PHP_SELF"].'" name="add">'."\n";
     $tag .= '<input type="hidden" name="action" value="'.$action.'" />'."\n";
@@ -645,43 +667,36 @@ function form_add_domain_2 ($domain_new,$action)
 
     $tag .= '<table class="data">'."\n";
 
-    $tag .= '<tr><td>'.$lang["domain"].'</td>'."\n";
+    $tag .= '<tr><td>'._("Domain").'</td>'."\n";
     $tag .= '<td colspan="2"><b>'.$domain_new.'</b></td></tr>'."\n";
 
-    $tag .= '<tr><td>'.$lang["password"].'</td>'."\n";
+    $tag .= '<tr><td>'._("Password").'</td>'."\n";
     $tag .= '<td colspan="2"><input type="password" name="password1" value="" size="15" maxlength="15" /></td></tr>'."\n";
 
-    $tag .= '<tr><td>'.$lang["repeat_password"].'</td>'."\n";
+    $tag .= '<tr><td>'._("Confirm Password").'</td>'."\n";
     $tag .= '<td colspan="2"><input type="password" name="password2" value="" size="15" maxlength="15" /></td></tr>'."\n";
     
-    $tag .= '<tr><td>'."\n";
-
-    // Domain Values
-    foreach ($pv as $name => $p_value)
-    {
-	if (isset($p_value["DOMAIN"]["ATTRIBUTES"]))
-	    $tag .= form_template('domain',$p_value["DOMAIN"]["ATTRIBUTES"],$values)."\n";
-    }
-    $tag .= '</td></tr>'."\n";
-
-    $i = 0;
-
     foreach ($pv as $name => $p_value)
     {
         if ($p_value["ISDOMAINRELATED"])
         {
-            if ($i%2 !=0)
-                $class='data';
-            else
-                $class='zata';
+            $class = 'pluginActive';
 
-            $tag .= '<tr valign="top" class="'.$class.'"><td>'."\n";
-            $tag .= '<input type="checkbox" name="confirm[]" value="'.$name.'" checked="checked" />'."\n";
-            $tag .= '<b>'.$p_value["LABEL"].'</b>'."\n";
+            $tag .= '<tr valign="top" class="'.$class.'" id="'.$name.'"><td>'."\n";
+            $tag .= '<input type="checkbox" name="confirm[]" value="'.$name.'" checked="checked" onclick="JavaScript:testing(this,\''.$name.'\')" />'."\n";
+            $tag .= '<strong>'.$p_value["LABEL"].'</strong>'."\n";
             $tag .= '</td><td>'."\n";
 
+	    // Load domain values
+	    if (isset($p_value["DOMAIN"]["ATTRIBUTES"]))
+	    {
+		$tag .= form_template('domain',$p_value["DOMAIN"]["ATTRIBUTES"],$values)."\n";
+	    }
+
             if (isset($p_value["POSTMASTER"]["ATTRIBUTES"]))
-		$tag .= form_template($name,$p_value["POSTMASTER"]["ATTRIBUTES"],$values)."\n";
+	    {
+		$tag .= form_template($name,$p_value["POSTMASTER"]["ATTRIBUTES"], $values_postmaster)."\n";
+	    }
 
             $tag .= '</td></tr>'."\n";
         }
@@ -700,7 +715,6 @@ function form_add_domain_2 ($domain_new,$action)
 
 function form_add_account ()
 {
-    global $lang;
     global $domain;
 
     $tag = '<form method="post" action="'.$_SERVER["PHP_SELF"].'" name="add_account">'."\n";
@@ -710,7 +724,7 @@ function form_add_account ()
         $tag .= $_POST["account_new"];
     $tag .= '" />';
     $tag .= '@'.$domain;
-    $tag .= '<input type="submit" value="'.$lang["add_account"].'" />'."\n";
+    $tag .= '<input type="submit" value="'._("Add new account").'" />'."\n";
     $tag .= '</form>'."\n\n";
 
     return $tag;
@@ -720,22 +734,21 @@ function form_add_account ()
 *
 **/
 
-function form_add_account_2 ($account_new,$action)
+function form_add_account_2 ($account_new,$action,$values)
 {
-    global $lang;
     global $plugins;
     global $pv;
     global $pn;
     global $domain;
-    global $cn;
+    global $givenName;
     global $sn;
-    global $values;
+    #global $values;
     global $plugins_exclusion;
 
     if (in_array($action,array('modify_account','update_account')))
-	$submit_label = $lang["modify_account"];
+	$submit_label = _("Modify account");
     else
-	$submit_label = $lang["add_account"];
+	$submit_label = _("Add new account");
 
     $tag = '<form method="post" action="'.$_SERVER["PHP_SELF"].'" name="add">'."\n";
     $tag .= '<input type="hidden" name="action" value="'.$action.'" />'."\n";
@@ -743,19 +756,19 @@ function form_add_account_2 ($account_new,$action)
 
     $tag .= '<table class="data">'."\n";
 
-    $tag .= '<tr><td>'.$lang["account"].'</td>'."\n";
+    $tag .= '<tr><td>'._("Account").'</td>'."\n";
     $tag .= '<td colspan="2"><b>'.$account_new.'</b></td></tr>'."\n";
 
-    $tag .= '<tr><td>'.$lang["password"].'</td>'."\n";
+    $tag .= '<tr><td>'._("Password").'</td>'."\n";
     $tag .= '<td colspan="2"><input type="password" name="password1" value="" size="15" maxlength="15" /></td></tr>'."\n";
 
-    $tag .= '<tr><td>'.$lang["repeat_password"].'</td>'."\n";
+    $tag .= '<tr><td>'._("Confirm Password").'</td>'."\n";
     $tag .= '<td colspan="2"><input type="password" name="password2" value="" size="15" maxlength="15" /></td></tr>'."\n";
 
-    $tag .= '<tr><td>'.$lang["cn"].'</td>'."\n";
-    $tag .= '<td colspan="2"><input type="text" name="cn" value="'.$cn.'" size="15" maxlength="50" /></td></tr>'."\n";
+    $tag .= '<tr><td>'._("Name").'</td>'."\n";
+    $tag .= '<td colspan="2"><input type="text" name="givenname" value="'.$givenName.'" size="15" maxlength="50" /></td></tr>'."\n";
 
-    $tag .= '<tr><td>'.$lang["sn"].'</td>'."\n";
+    $tag .= '<tr><td>'._("Surname").'</td>'."\n";
     $tag .= '<td colspan="2"><input type="text" name="sn" value="'.$sn.'" size="15" maxlength="50" /></td></tr>'."\n";
     
     $i = 0;
@@ -779,17 +792,12 @@ function form_add_account_2 ($account_new,$action)
 	    if ($show_form)
 		if ($p_value["ISACCOUNTRELATED"])
 		{
-		    if ($i%2 !=0)
-			$class='data';
-		    else
-			$class='zata';
-
-		    $tag .= '<tr valign="top" class="'.$class.'"><td>'."\n";
+		    $tag .= '<tr valign="top" class="pluginActive" id="'.$name.'"><td>'."\n";
 
 		    if (in_array($name,$plugins_exclusion))
 			$tag .= '<input type="radio" name="confirm[]" value="'.$name.'" checked="checked" />'."\n";
 		    else
-			$tag .= '<input type="checkbox" name="confirm[]" value="'.$name.'" checked="checked" />'."\n";
+			$tag .= '<input type="checkbox" name="confirm[]" value="'.$name.'" checked="checked" onClick="testing(this,\''.$name.'\')" />'."\n";
 
 		    $tag .= '<b>'.$p_value["LABEL"].'</b>'."\n";
 		    $tag .= '</td><td>'."\n";
@@ -820,11 +828,11 @@ function navigation ($initial)
     global $domain;
     global $account;
     global $mail;
-    global $lang;
     global $action;
 
-    $tag = '<div class="navigation">'."\n";
-    $tag .= '<a href="main.php?domain=NONE&amp;initial=">'.$lang["all_domains"]."</a>"."\n";
+    $tag = '<div id="navBar">'."\n";
+    $tag .= '<div class="navigation">'."\n";
+    $tag .= '<a href="main.php?domain=NONE&amp;initial=">'._("All domains")."</a>"."\n";
     if ($domain)
     {
         $tag .= " &gt; ".'<a href="main.php?action=domain_view&amp;mail=NONE&amp;domain='.$domain.'&amp;initial=">';
@@ -840,12 +848,12 @@ function navigation ($initial)
 
     $tag .= '<div class="navigation">'."\n";
 
-    $tag .= '<a href="?action='.$action.'&amp;initial=&amp;domain='.$domain.'">'.$lang["all"].'</a> - '."\n";
+    $tag .= '<a href="?action='.$action.'&amp;initial=&amp;domain='.$domain.'">'._("All").'</a> - '."\n";
 
     for ($i="A"; $i != "AA"; $i++)
     {
         if ($i == $initial)
-            $tag .= '<font class="warning">'.$i.'</font>';
+            $tag .= '<span>'.$i.'</span>';
         else
         {
             $tag .= '<a href="?action='.$action.'&amp;initial='.$i;
@@ -863,7 +871,7 @@ function navigation ($initial)
     for ($i='0'; $i != '10'; $i++)
     {
         if ($i == $initial)
-            $tag .= '<font class="warning">'.$i.'</font>'."\n";
+            $tag .= '<span>'.$i.'</span>'."\n";
         else
         {
             $tag .= '<a href="?action='.$action.'&amp;initial='.$i;
@@ -876,7 +884,8 @@ function navigation ($initial)
             $tag .= ' - '."\n";
     }
 
-    $tag .= '</div>';
+    $tag .= '</div>'."\n";
+    $tag .= '</div>'."\n\n";
 
     return $tag;
 }
@@ -889,7 +898,6 @@ function navigation ($initial)
 
 function trueorfalse($table,$value,$field,$reverse)
 {
-    global $lang;
     global $minAuthLevel;
 
     $tag = '';
@@ -908,8 +916,8 @@ function trueorfalse($table,$value,$field,$reverse)
 	$img = $value;
     }
 
-    $false_label = (isset($lang[$false]) ? $lang[$false] : $false);
-    $true_label = (isset($lang[$true]) ? $lang[$true] : $true);
+    $false_label = ($false == 'FALSE' ? _("NO") : _("YES"));
+    $true_label = ($true == 'TRUE' ? _("YES") : _("NO"));
     
     $tag .= '<img src="./img/'.$img.'.png" alt="" border="0" /> ';
 
@@ -936,28 +944,72 @@ function trueorfalse($table,$value,$field,$reverse)
 *
 */
 
-function action_select($group_actions)
+function action_select($dispaly)
 {
-    global $lang;
+    global $pv;
 
+    $group_actions = array();
+    
+    // Alias require immediate cancellation
+    if ($_SESSION["phamm"]["pn"] == 'alias')
+	$group_actions[] = "account;delete;TRUE;Delete;0";
+    
+    $attribute_array = array();
+    $p_active = $_SESSION["phamm"]["pn"];
+    $values = ($pv[$p_active]);
+
+    if ($dispaly == 'domain')
+    {
+	if (isset($values["DOMAIN"]["ATTRIBUTES"]))
+	    $attribute_array = array_merge($attribute_array,$values["DOMAIN"]["ATTRIBUTES"]);
+	if (isset($values["POSTMASTER"]["ATTRIBUTES"]))
+	    $attribute_array = array_merge($attribute_array,$values["POSTMASTER"]["ATTRIBUTES"]);
+    }
+    elseif ($dispaly == 'account')
+    {
+	if (isset($values["ACCOUNT"]["ATTRIBUTES"]))
+	    $attribute_array = array_merge($attribute_array,$values["ACCOUNT"]["ATTRIBUTES"]);
+    }
+
+    foreach ($attribute_array as $attribute_name => $attribute_values)
+    {
+        $is_bool = (isset($attribute_values["BOOL"]) ? $attribute_values["BOOL"] : null);
+        $is_table = (isset($attribute_values["TABLE"]) ? $attribute_values["TABLE"] : null);
+        $prettyname = (isset($attribute_values["PRETTYNAME"]) ? $attribute_values["PRETTYNAME"] : null);
+        $is_reverse = (isset($attribute_values["REVERSE"]) ? 1 : 0);
+
+        if ($is_bool && $is_table)
+        {
+	    $group_actions[] = $dispaly.';'.$attribute_name.';TRUE;'.$prettyname.';'.$is_reverse;
+	    $group_actions[] = $dispaly.';'.$attribute_name.';FALSE;'.$prettyname.';'.$is_reverse;
+	}
+    }
+    
     // Open <form> tag inside domains_list() function
+    $tag = '';
+    $tag .= '<input type="hidden" name="action" value="group_actions" />'."\n";
 
-    $tag = '<table border="0">';
-
-    $tag .= '<tr>';
-    $tag .= '<td class="note" colspan="2">';
-    $tag .= '<select name="action">';
-    $tag .= '<option value="">'.$lang["select_an_action"].'</option>'."\n";
+    $tag .= '<select name="command">';
+    $tag .= '<option value="">'._("...execute a command").'</option>'."\n";
     
     foreach ($group_actions as $action)
     {
-	$label = (isset($lang[$action]) ? $lang[$action] : $action);
-	$tag .= '<option value="'.$action.'">'.$label.'</option>'."\n";
+	# @todo
+	$label = explode(';',$action);
+	$tag .= '<option value="'.$action.'">'._("Set").' '.gettext($label[3]).' ';
+	if ($label[4] == 1)
+	{
+	    $reverse_label_2 = ($label[2] == 'TRUE' ? 'FALSE' : 'TRUE');
+	    $tag .= gettext($reverse_label_2);
+	}
+	else
+	    $tag .= gettext($label[2]);
+	$tag .= '</option>'."\n";
     }
-    $tag .= "</select>";
-    $tag .= '<input type="submit" value="'.$lang["execute_command"].'" />'."\n";
 
-    $tag .= "</td></tr></table>"."\n\n";
+    $tag .= "</select>";
+    $tag .= '<input type="submit" value="'._("Execute command").'" />'."\n";
+    
     $tag .= "</form>"."\n\n";
 
     return $tag;
@@ -977,7 +1029,7 @@ function tof_icon($table,$value,$tof_action,$reverse=null,$cron=null)
 
     $tag = '<div align="center">';
     $tag .= '<a href="?'.$table.'&amp;action='.$tof_action.'">';
-    $tag .= '<img src="./img/'.$value.'.png" alt="" border="0" />';
+    $tag .= '<img src="./img/'.$value.'.png" alt="'.$value.'" border="0" />';
     $tag .= '</a></div>';
 
     return $tag;
@@ -997,25 +1049,27 @@ function date_input($name,$current_date,$format='ymd')
     $tag .= '<select name="'.$name.'[day]">';
     for ($i=1; $i<=31; $i++)
     {
+	$i_f = ($i < 10 ? '0'.$i : $i);
 	$selected = ($i == $day ? 'selected="selected"' : '');
-	$tag .= '<option value="'.$i.'" '.$selected.'>'.$i.'</option>';
+	$tag .= '<option value="'.$i_f.'" '.$selected.'>'.$i_f.'</option>';
     }
     $tag .= "</select>";
 
-    // Month
+    // Months
     $tag .= '<select name="'.$name.'[month]">';
     for ($i=1; $i<=12; $i++)
     {
+	$i_f = ($i < 10 ? '0'.$i : $i);
 	$selected = ($i == $month ? 'selected="selected"' : '');
-	$tag .= '<option value="'.$i.'" '.$selected.'>'.$i.'</option>';
+	$tag .= '<option value="'.$i_f.'" '.$selected.'>'.$i_f.'</option>';
     }
     $tag .= "</select>";
 
-    // Year
+    // Years
     $this_year = date('Y');
 
-    $min_year = ( $this_year - 1);
-    $max_year = ( $this_year +4 );
+    $min_year = ( $this_year - 1 );
+    $max_year = ( $this_year + 4 );
 
     $tag .=  '<select name="'.$name.'[year]">';
     for ($i=$min_year; $i<$max_year; $i++)
@@ -1057,22 +1111,20 @@ function locale_select()
 
 function form_catch_all($domain)
 {
-    global $lang;
-
-    $tag = phamm_print_message ('message',$lang["catch_all"]);
+    $tag = '<div class="message">'._("Catch-all").'</div>';
 
     $tag .= '<form method="post" action="'.$_SERVER["PHP_SELF"].'" name="login">'."\n";
     $tag .= '<input type="hidden" name="action" value="insert_account" />'."\n";
     $tag .= '<input type="hidden" name="account_new" value="@'.$domain.'" />'."\n";
     $tag .= '<input type="hidden" name="values[alias][accountactive]" value="TRUE" />'."\n";
     $tag .= '<input type="hidden" name="confirm[]" value="alias" />'."\n";
-    $tag .= '<input type="hidden" name="cn" value="Catch All" />'."\n";
-    $tag .= '<input type="hidden" name="sn" value="Catch All" />'."\n";
+    $tag .= '<input type="hidden" name="givenname" value="Catch" />'."\n";
+    $tag .= '<input type="hidden" name="sn" value="All" />'."\n";
     $tag .= '<input type="hidden" name="password1" value="" />'."\n";
     $tag .= '<input type="hidden" name="password2" value="" />'."\n";
     $tag .= '<textarea name="values_multi[alias][maildrop]" cols="35" rows="3">';
     $tag .= '</textarea><br/>';
-    $tag .= '<input type="submit" value="'.$lang["add_catch_all"].'" />'."\n";
+    $tag .= '<input type="submit" value="'._("Add catch-all address").'" />'."\n";
     $tag .= '</form>'."\n";
 
     return $tag;
