@@ -1,9 +1,7 @@
 <?php
-
+// Start PHP session
 session_start();
 
-error_reporting(E_ALL);
-
 // Set the HTTP Charset Parameter as UTF-8
 header("Content-type: text/html; charset=utf-8");
 
@@ -28,20 +26,39 @@ if (FORCE_SSL == 1 && (!isset($_SERVER['HTTPS']) || $_SERVER['HTTPS'] != "on"))
 // Set PHP error level
 phamm_php_error_level();
 
-$page_start = page_start();
 $page_end = page_end();
 $page_exit = page_exit();
 
-// Set language
+/////////////////////////////////////////////////////////////////
+// Set language and locale
 if (isset($_GET["language"]))
     $_SESSION["language"] = locale_set($_GET["language"]);
 
+// Set default language from user browser
 if (!isset($_SESSION["language"]))
-    $_SESSION["language"] = $language;
+    $_SESSION["language"] = DEFAULT_LANGUAGE;
 
-$lang = locale_load($_SESSION["language"]);
+$locale = $_SESSION["language"];
 
-phamm_print_xhtml($page_start);
+putenv("LC_ALL=$locale");
+setlocale(LC_ALL, $locale);
+bindtextdomain("messages", "../locales");
+textdomain("messages");
+bind_textdomain_codeset("messages","UTF-8");
+//
+/////////////////////////////////////////////////////////////////
+    
+/////////////////////////////////////////////////////////////////
+// Set action
+if (isset($_POST["action"]))
+    $action = $_POST["action"];
+elseif (isset($_GET["action"]))
+    $action = $_GET["action"];
+else
+    $action = null;
+/////////////////////////////////////////////////////////////////
+
+phamm_print_xhtml (page_start());
 
 $connect = phamm_ldap_connect ();
 
@@ -50,7 +67,10 @@ $pv = plugins_load();
 
 if (!$connect)
 {
-    phamm_print_message ('error',$lang["error_connection"]);
+    phamm_print_message ('error',_("Connection to LDAP Server Failed!"));
+    
+    print phamm_error();
+
     echo $page_exit;
 }
 
@@ -61,12 +81,21 @@ if (!login_check() && isset($_POST["login_username"]) && isset($_POST["login_pas
 {
     $proposed = login_dn_costructor($_POST["login_username"]);
 
-    $r_bind = login_try($connect, $proposed, $_POST["login_password"],$_POST["login_username"]);
+    $r_bind = @login_try($connect, $proposed, $_POST["login_password"],$_POST["login_username"]);
 
     phamm_log ('',$_POST["login_username"],'login',$r_bind);
 
     if (!$r_bind)
-        phamm_print_message('error',$lang["invalid_credential"]);
+    {
+	$error_code = ldap_errno($connect);
+
+	if ($error_code == '49')
+	    phamm_print_message('error',_("Login Username or Password not valid."));
+	elseif ($error_code == '-1')
+	    phamm_print_message('error',_("Can't contact LDAP server"));
+	else   
+	    print phamm_print_message('error',_("Generic Error: ").ldap_error($connect));
+    }
 }
 
 // Logout
@@ -76,7 +105,7 @@ if (isset($_GET["exit"]))
     
     logout();
 
-    phamm_print_message ('message',$lang["logout_message"]);
+    phamm_print_message ('message',_("Bye!"));
 
     refresh ( 'main.php', $force_meta = false, REFRESH_TIME );
 
@@ -123,28 +152,19 @@ elseif(login_check())
     else
 	$domain = $_SESSION["phamm"]["domain"];
 
-    // Set action
-    if (isset($_POST["action"]))
-        $action = $_POST["action"];
-    elseif (isset($_GET["action"]))
-	$action = $_GET["action"];
-    // Default action
-    else
-	    $action = null;
-    
-    $group_actions = array_merge($group_actions_accounts,$group_actions_domains);
-
     // Overwrite action for user login
     if (!in_array($action,array('update_account')) && $_SESSION["login"]["level"] == 2)
 	    $action = 'modify_account';
     
     // Overwrite action for Postmaster
-    elseif (!in_array($action,$group_actions) && !in_array($action,array('add_account','insert_account','modify_account','update_account','domain_property','catch_all')) && $_SESSION["login"]["level"] == 4)
+    elseif (!in_array($action,array('add_account','insert_account','modify_account','update_account','domain_property','catch_all','group_actions')) && $_SESSION["login"]["level"] == 4)
 	$action = 'domain_view';
 
     // Link to logount and language select
     phamm_print_xhtml ('<table width="100%"><tr><td align="left">');
-    phamm_print_xhtml ( "<a href=\"?exit=1\">".$lang["logout"].' '.$_SESSION["login"]["username"].'</a></td><td align="right">' );
+    phamm_print_xhtml ("<a href=\"?exit=1\">");
+    printf (_("Logout %s"),$_SESSION["login"]["username"]);
+    phamm_print_xhtml ('</a></td><td align="right">');
 
     phamm_print_xhtml (locale_select());
     phamm_print_xhtml ('</td></tr></table><hr/>');
@@ -157,13 +177,6 @@ elseif(login_check())
 
     // echo $action;
 
-    if (in_array($action,$group_actions))
-    {
-        // Re-write $action in $group_action
-        $group_action = $action;
-        $action = 'group_actions';
-    }
-    
     switch ($action) :
 
     // group_actions
@@ -172,23 +185,29 @@ elseif(login_check())
     // List of accounts/domains to modify
     if (isset($_POST["accounts"]))
 	$values = $_POST["accounts"];
-    elseif (isset($_POST["domains"]))
-	$values = $_POST["domains"];
-    elseif (isset($_GET["domains"]))
-	$values = $_GET["domains"];
     elseif (isset($_GET["accounts"]))
 	$values = $_GET["accounts"];
 
-    foreach ($values as $k => $v)
-	phamm_print_message('success',$lang["modify"].' '.$k);
+    if (isset($_POST["domains"]))
+	$values = $_POST["domains"];
+    elseif (isset($_GET["domains"]))
+	$values = $_GET["domains"];
 
-    $r = group_actions ($group_action,$values);
+    if (isset($_POST["command"]))
+	$command = $_POST["command"];
+    elseif (isset($_GET["command"]))
+	$command = $_GET["command"];
+
+    foreach ($values as $k => $v)
+	phamm_print_message('success',sprintf(_("%s modified"),$k));
+
+    $r = group_actions ($command,$values);
     
     phamm_log ($pn,$_SESSION["login"]["username"],$action,$r);
 
     if ($r)
     {
-	$ga = explode(';',$group_action);
+	$ga = explode(';',$command);
 
         if ($ga[0] == 'account')
             refresh ('main.php?action=domain_view&amp;domain='.$domain, $force_meta = false, REFRESH_TIME);
@@ -197,7 +216,9 @@ elseif(login_check())
     }
     else
     {
-        phamm_print_message('error',$lang["warning"]);
+        phamm_print_message('error',_("Changes have not performed"));
+        
+	print phamm_error();
     }
 
     break;
@@ -208,12 +229,11 @@ case "add_domain" :
 
     $syntax = check_syntax('domain',$_POST["domain_new"]);
 
-
     if ($syntax)
-        phamm_print_xhtml ( form_add_domain_2 ($_POST["domain_new"],'insert_domain') );
+        phamm_print_xhtml ( form_add_domain_2 ($_POST["domain_new"],'insert_domain' , $values=array(), $values=array()));
     else
     {
-        phamm_print_message('error',$lang["warning"]);
+        phamm_print_message('error',_("Syntax not valid or special chars found in domain name"));
         phamm_print_xhtml ( form_add_domain ($_POST["domain_new"]) );
     }
 
@@ -229,13 +249,17 @@ case "insert_domain" :
     $password1 = $_POST["password1"];
     $password2 = $_POST["password2"];
 
-    $wrong_pw = wrong_pw ($password1,$password2);
+    $wrong_pw_msg = wrong_pw ($password1,$password2);
 
-    if ($wrong_pw)
+    if ($wrong_pw_msg)
     {
-        phamm_print_message ('error',$wrong_pw);
-        phamm_print_xhtml ( form_add_domain_2 ($_POST["domain_new"],'insert_domain') );
-	phamm_log ($pn,$_SESSION["login"]["username"],$action.' '.$domain_new.' '.$wrong_pw,0);
+	/*echo '<pre>';
+	print_r($values);
+	echo '</pre>'; */
+
+        phamm_print_message ('error',$wrong_pw_msg);
+        phamm_print_xhtml ( form_add_domain_2 ($_POST["domain_new"], 'insert_domain', $values, $values ) );
+	phamm_log ($pn,$_SESSION["login"]["username"],$action.' '.$domain_new.' '.$wrong_pw_msg,0);
     }
 
 
@@ -253,9 +277,9 @@ case "insert_domain" :
 	// Purge values
 	$values_purged = purge_empty_values($entry); // @todo 2th value
 	
-        $r = phamm_add ('vd='.$domain_new.','.LDAP_BASE,$values_purged);
+        $r_d = @phamm_add ('vd='.$domain_new.','.LDAP_BASE,$values_purged);
     
-	phamm_log ($pn,$_SESSION["login"]["username"],$action.' '.$domain_new,$r);
+	phamm_log ($pn,$_SESSION["login"]["username"],$action.' '.$domain_new,$r_d);
 
         unset($entry);
 
@@ -296,7 +320,7 @@ case "insert_domain" :
         }
 
 	// Add postmaster alias
-        $r = phamm_add ('cn=postmaster,vd='.$domain_new.','.LDAP_BASE,$entry);
+        $r_p = @phamm_add ('cn=postmaster,vd='.$domain_new.','.LDAP_BASE,$entry);
         
 	$entry_abuse["objectclass"][0]	= "top";
         $entry_abuse["objectclass"][1]	= "VirtualMailAlias";
@@ -309,15 +333,23 @@ case "insert_domain" :
         $entry_abuse["lastChange"] = time();
 	
 	// Add abuse alias
-        $r = phamm_add ('mail=abuse@'.$domain_new.',vd='.$domain_new.','.LDAP_BASE,$entry_abuse);
+        $r_a = @phamm_add ('mail=abuse@'.$domain_new.',vd='.$domain_new.','.LDAP_BASE,$entry_abuse);
 
-        if ($r)
+        if ($r_d && $r_p && $r_a)
         {
-            phamm_print_message('success',$domain_new.' '.$lang["added"]);
+            phamm_print_message('success',sprintf(_("Domain %s successfully added"),$domain_new));
             refresh ('main.php', $force_meta = false, REFRESH_TIME);
         }
+        elseif (!$r_d)
+	{
+            phamm_print_message('error',sprintf(_("domain %s not added!"),$domain_new));
+            print phamm_error();
+	}
         else
-            phamm_print_message('error',$lang["error"].': '.$domain_new.' '.$lang["not_added"]);
+	{
+            phamm_print_message('error',sprintf(_("An Unexpected Error Occurred during %s Addition!"),$domain_new));
+            print phamm_error();
+	}
 
     }
 
@@ -335,14 +367,14 @@ case "add_account" :
     $account_exists = phamm_list('vd='.$domain.','.LDAP_BASE,"(mail=".$_POST["account_new"]."@".$domain.")",array('mail'));
 
     if ($syntax && $account_exists["count"] == 0)
-        phamm_print_xhtml ( form_add_account_2 ($_POST["account_new"].'@'.$domain,'insert_account') );
+        phamm_print_xhtml ( form_add_account_2 ($_POST["account_new"].'@'.$domain,'insert_account', array()) );
 
     else
     {
 	if ($account_exists["count"] > 0)
-	    phamm_print_message('error',$lang["account_or_alias_exists"]);
+	    phamm_print_message('error',_("Account or Alias already exists"));
 	if (!$syntax)
-	    phamm_print_message('error',$lang["warning"]);
+	    phamm_print_message('error',_("Special Characters not Allowed in E-mail address"));
         phamm_print_xhtml ( form_add_account ($_POST["account_new"]) );
     }
 
@@ -355,21 +387,24 @@ case "modify_account" :
 
     $values = self_values ($dn);
 
-    $cn = $values[0]["cn"][0];
-    $sn = $values[0]["sn"][0];
+    if (isset($values[0]["sn"][0]))
+	$sn = $values[0]["sn"][0];
+
+    if (isset($values[0]["givenname"][0]))
+	$givenName = $values[0]["givenname"][0];
 
     // ////////////////////////////////////////////////////////////
     // Static warning @todo
     if (!($values[0]["amavisspamkilllevel"][0] >= $values[0]["amavisspamtag2level"][0] && $values[0]["amavisspamtag2level"][0] >= $values[0]["amavisspamtaglevel"][0]))
-        phamm_print_message ('warning',$lang["warning_spam_tag_level"]);
+        phamm_print_message ('warning',_("SPAM Tags level are not set correctly!"));
     if ($values[0]["forwardactive"][0] == "TRUE" && isset($values[0]["vacationforward"]["count"]))
-        phamm_print_message ('warning',$lang["warning_double_forward"]);
+        phamm_print_message ('warning',_("do not activate Forward and Vacation Forward in the same time!"));
     if ($values[0]["forwardactive"][0] == "TRUE" && !isset($values[0]["maildrop"]))
-        phamm_print_message ('warning',$lang["warning_forward_destination_missed"]);
+        phamm_print_message ('warning',_("please, insert a forward destination or disable Forward!"));
     //
     // ////////////////////////////////////////////////////////////
 
-    phamm_print_xhtml ( form_add_account_2 ($values[0]["mail"][0], 'update_account') );
+    phamm_print_xhtml ( form_add_account_2 ($values[0]["mail"][0], 'update_account', $values) );
 
     break;
 
@@ -380,7 +415,7 @@ case "domain_view" :
     phamm_print_xhtml ( form_add_account() );
 
     // Link to modify domain Property
-    phamm_print_xhtml ( '<a href="?action=domain_property&amp;domain='.$domain.'">'.$lang["domain_property"].'</a> ' );
+    phamm_print_xhtml ( '<a href="?action=domain_property&amp;domain='.$domain.'">'._("Domain property").'</a> ' );
 
     //Special link for catch-all
     if (in_array($pn,array('mail','alias')))
@@ -390,9 +425,9 @@ case "domain_view" :
 	$values = phamm_search ($catch_all_dn,'mail=@'.$domain,array('mail'));
 
 	if (isset($values[0]["mail"][0]))
-	    phamm_print_message('warning','<br/>'.$lang["catch_all"].' '.$lang["active"]);
+	    phamm_print_message('warning','<br/>'._("Catch all active"));
 	else
-	    phamm_print_xhtml ( ' - <a href="?action=catch_all&amp;domain='.$domain.'">'.$lang["catch_all"].'</a>' );
+	    phamm_print_xhtml ( ' - <a href="?action=catch_all&amp;domain='.$domain.'">'._("Catch all").'</a>' );
     }
 
     phamm_print_xhtml ('<br/>');
@@ -404,7 +439,7 @@ case "domain_view" :
         $values = array_merge($values,$pv[$pn]["ACCOUNT"]);
 
     phamm_print_xhtml ( accounts_list($domain,$values,$initial) );
-    phamm_print_xhtml ( action_select($group_actions_accounts) );
+    phamm_print_xhtml ( action_select('account') );
 
     break;
 
@@ -419,8 +454,9 @@ case "insert_account" :
     $account_new = $_POST["account_new"];
     $password1 = $_POST["password1"];
     $password2 = $_POST["password2"];
-    $cn = $_POST["cn"];
     $sn = $_POST["sn"];
+    $givenName = $_POST["givenname"];
+
     
     // Create empty array
     $entry = array();
@@ -429,28 +465,28 @@ case "insert_account" :
     $values_multi_purged = array();
     $values_date_purged = array();
 
-    $check_cn = check_syntax ('name',$cn,2);
-    $check_sn = check_syntax ('name',$sn,2);
+    $check_sn = check_syntax ('name',$sn,1);
+    $check_givenName = check_syntax ('name',$givenName,1);
 
     // Is alias account ?
     $is_alias = in_array('alias',$confirm);
     
     if ($is_alias)
-	$wrong_pw = wrong_pw ($password1,$password2,0);
+	$wrong_pw_msg = wrong_pw ($password1,$password2,0);
     else
-	$wrong_pw = wrong_pw ($password1,$password2);
+	$wrong_pw_msg = wrong_pw ($password1,$password2);
 
-    if ($wrong_pw)
-        phamm_print_message ('error',$wrong_pw);
-    if (!$check_cn)
-        phamm_print_message ('error',$lang["cn_is_not_valid"]);
+    if ($wrong_pw_msg)
+        phamm_print_message ('error',$wrong_pw_msg);
+    if (!$check_givenName)
+        phamm_print_message ('error',_("Name is not valid"));
     if (!$check_sn)
-        phamm_print_message ('error',$lang["sn_is_not_valid"]);
+        phamm_print_message ('error',_("Surname is not valid"));
 
-    if ($wrong_pw || !$check_cn || !$check_sn)
+    if ($wrong_pw_msg || !$check_givenName || !$check_sn)
     {
-        phamm_print_xhtml ( form_add_account_2 ($_POST["account_new"], 'insert_account' ));
-	phamm_log ($pn,$_SESSION["login"]["username"],$action.' '.$account_new.' '.$wrong_pw,0);
+        phamm_print_xhtml ( form_add_account_2 ($_POST["account_new"], 'insert_account', $values ));
+	phamm_log ($pn,$_SESSION["login"]["username"],$action.' '.$account_new.' '.$wrong_pw_msg,0);
     }
 
     else
@@ -480,10 +516,11 @@ case "insert_account" :
 
         $entry["mail"] = $mail;
         $entry["userPassword"] = password_hash($password1);
-        $entry["cn"] = $cn;
         $entry["sn"] = $sn;
+        $entry["givenname"] = $givenName;
+        $entry["cn"] = $givenName.' '.$sn;
         $entry["lastChange"] = time();
-        $entry["creationDate"] = date('Ymd');
+        $entry["creationDate"] = date('YmdHi');
 
 	$entry = purge_empty_values($entry);
 
@@ -520,7 +557,7 @@ case "insert_account" :
 	    }
 	}
 
-        $r = phamm_add ('mail='.$mail.',vd='.$domain.','.LDAP_BASE,$entry);
+        $r = @phamm_add ('mail='.$mail.',vd='.$domain.','.LDAP_BASE,$entry);
 	
 	phamm_log ($pn,$_SESSION["login"]["username"],$action.' '.$mail,$r);
 
@@ -543,9 +580,13 @@ case "insert_account" :
 		$headers .= "Message-ID: <".time()."@".$_SERVER['SERVER_NAME'].">".$eol;
 		$headers .= "X-Mailer: PHP v".phpversion().$eol;
 
-		## $headers .= "From: <".$welcome_sender.">".$eol;
-		$headers .= "From: <postmaster@".$domain.">".$eol;
-		$headers .= "Bcc: <".$welcome_bcc.">".$eol;
+		if (isset($welcome_sender))
+		    $headers .= "From: <".$welcome_sender.">".$eol;
+		else
+		    $headers .= "From: <postmaster@".$domain.">".$eol;
+
+		if (isset($welcome_bcc))
+		    $headers .= "Bcc: <".$welcome_bcc.">".$eol;
 
 		// Skip Welcome Message if is a Catch-all account
 		if ($mail != '@'.$domain)
@@ -561,12 +602,15 @@ case "insert_account" :
 		phamm_log ($pn,$_SESSION["login"]["username"],'sent welcome message to '.$mail,$r);
 	    }
 
-            phamm_print_message('success',$account_new.' '.$lang["added"]);
+            phamm_print_message('success',sprintf(_("Account %s successfully added"),$account_new));
 
             refresh ('main.php?action=domain_view&amp;domain='.$domain, $force_meta = false, REFRESH_TIME);
         }
         else
-            phamm_print_message('error',$lang["error"].': '.$account_new.' '.$lang["not_added"]);
+	{
+            phamm_print_message('error',sprintf(_("%s not added!"), $account_new));
+            print phamm_error();
+	}
     }
 
     break;
@@ -584,8 +628,8 @@ case "update_account" :
     $account = (isset($_POST["account_new"]) ? $_POST["account_new"] : null);
     $password1 = $_POST["password1"];
     $password2 = $_POST["password2"];
-    $cn = (isset($_POST["cn"]) ? $_POST["cn"] : null);
     $sn = (isset($_POST["sn"]) ? $_POST["sn"] : null);
+    $givenName = (isset($_POST["givenname"]) ? $_POST["givenname"] : null);
 
     // Create empty array
     $entry = array();
@@ -594,24 +638,25 @@ case "update_account" :
     $values_multi_purged = array();
     $values_date_purged = array();
 
-    $entry["cn"] = $cn;
     $entry["sn"] = $sn;
+    $entry["givenname"] = $givenName;
+    $entry["cn"] = $givenName.' '.$sn;
 
     // Tag and others
     $entry = purge_empty_values($entry);
 
-    if ($password1)
-        $wrong_pw = wrong_pw ($password1,$password2);
+    if ($password1 || $password2)
+        $wrong_pw_msg = wrong_pw ($password1,$password2);
     else
-        $wrong_pw = 0;
+        $wrong_pw_msg = 0;
 
-    if ($wrong_pw)
+    if ($wrong_pw_msg)
     {
 
-        phamm_print_message ('error',$wrong_pw);
-        phamm_print_xhtml ( form_add_account_2 ($account, 'insert_account' ));
+        phamm_print_message ('error',$wrong_pw_msg);
+        phamm_print_xhtml ( form_add_account_2 ($account, 'insert_account', $values ));
 	
-	phamm_log ($pn,$_SESSION["login"]["username"],$action.' '.$wrong_pw,0);
+	phamm_log ($pn,$_SESSION["login"]["username"],$action.' '.$wrong_pw_msg,0);
 
         break;
     }
@@ -621,7 +666,10 @@ case "update_account" :
 	foreach ( $confirm as $p_name )
 	{
 	    // Purge empty values
-	    $values_purged = purge_empty_values($values[$p_name],$pv[$p_name]["ACCOUNT"]["ATTRIBUTES"]);
+	    if (isset($pv[$p_name]["ACCOUNT"]))
+		$values_purged = purge_empty_values($values[$p_name],$pv[$p_name]["ACCOUNT"]["ATTRIBUTES"]);
+	    else
+		$values_purged = purge_empty_values($values[$p_name]);
 
 	    if (isset($values_multi[$p_name]))
 	    	$values_multi_purged_one = purge_empty_values($values_multi[$p_name]);
@@ -632,6 +680,12 @@ case "update_account" :
 	    $entry = array_merge($entry,$values_purged);
 	    $values_multi_purged = array_merge($values_multi_purged,$values_multi_purged_one);
 	    $values_date_purged = array_merge($values_date_purged,$values_date_purged_one);
+    
+	    // Del Values from checkbox
+	    if (isset($values_multi_del[$p_name]))
+	    {
+	        $rd = phamm_mod_del ('mail='.$mail.',vd='.$domain.','.LDAP_BASE,$values_multi_del[$p_name]);
+	    }
 	}
     }
 
@@ -641,7 +695,7 @@ case "update_account" :
     if (count($values_date_purged) > 0)
     {
 	foreach ($values_date_purged as $k_date => $v_date)
-	    $entry[$k_date] = $v_date["year"].'-'.$v_date["month"].'-'.$v_date["day"];
+	    $entry[$k_date] = $v_date["year"].$v_date["month"].$v_date["day"].'0000';
 
 
     }
@@ -670,13 +724,6 @@ case "update_account" :
 
     }
 
-    // Del Values from checkbox
-    if (isset($values_multi_del[$p_name]))
-    {
-        $rd = phamm_mod_del ('mail='.$mail.',vd='.$domain.','.LDAP_BASE,$values_multi_del[$p_name]);
-    }
-
-
     // This swith action to change mail or postmaster value
     if ($mail)
     {
@@ -694,6 +741,7 @@ case "update_account" :
 	// Skip static values cn and sn
 	unset($entry["cn"]);
 	unset($entry["sn"]);
+	unset($entry["givenname"]);
         
 	$entry["lastChange"] = time();
 
@@ -703,27 +751,33 @@ case "update_account" :
 	$r = phamm_modify ('cn=postmaster,vd='.$domain.','.LDAP_BASE,$entry);
 	
 	phamm_log ($pn,$_SESSION["login"]["username"],$action.' postmaster@'.$domain,$r);
+	
+	// Update domain values
+	$entry_domain = purge_empty_values($values["domain"]);
+	$r_d = phamm_modify ('vd='.$domain.','.LDAP_BASE,$entry_domain);
+	
+	phamm_log ($pn,$_SESSION["login"]["username"],'update_domain '.$domain,$r);
     }
 
     if ($r)
     {
-        phamm_print_message('success',$account.' '.$lang["updated"]);
+        phamm_print_message('success',sprintf("Account %s succesfully updated",$account));
 	refresh ('main.php?action=domain_view&amp;domain='.$domain, $force_meta = false, REFRESH_TIME);
     }
     else
-        phamm_print_message('error',$lang["error"].': '.$account.' '.$lang["not_updated"]);
+        phamm_print_message('error',sprintf(_("account %s not updated!"),$account));
 
     break;
 
 case "domain_property" :
     
-	// Load domain values
-	// $dn = 'vd='.$domain.','.LDAP_BASE;
-	$dn = 'cn=postmaster,vd='.$domain.','.LDAP_BASE;
-	$values = self_values ($dn);
+	$dn = 'vd='.$domain.','.LDAP_BASE;
+	$values = phamm_search ($dn,$filter="objectClass=VirtualDomain");
+	
+	$dn_postmaster = 'cn=postmaster,vd='.$domain.','.LDAP_BASE;
+	$values_postmaster = phamm_search ($dn_postmaster,$filter="cn=postmaster");
 
-	// action update_account => postmaster
-        phamm_print_xhtml ( form_add_domain_2 ($domain, 'update_account') );
+        phamm_print_xhtml ( form_add_domain_2 ($domain, 'update_account', $values, $values_postmaster ) );
     break;
 
 case "catch_all" :
@@ -763,13 +817,12 @@ default :
 	phamm_print_xhtml ( form_add_domain() );
 
 	phamm_print_xhtml ( domains_list($vds,$values) );
-	phamm_print_xhtml ( action_select($group_actions_domains) );
+	phamm_print_xhtml ( action_select('domain') );
     }
 
     break;
 
     endswitch;
-
 }
 
 echo $page_end;
